@@ -5,6 +5,7 @@
 from __future__ import absolute_import, print_function
 
 import simplejson
+import six
 
 from zope.component import getMultiAdapter, getUtility, queryMultiAdapter
 from zope.event import notify
@@ -145,7 +146,8 @@ class ResourceOperation(BatchingResourceMixin):
             # has its response batched.
             return True
 
-        if zope_isinstance(result, (basestring, dict, set, list, tuple)):
+        if zope_isinstance(
+                result, (bytes, six.text_type, dict, set, list, tuple)):
             # Ordinary Python data structures generally are not
             # batched.
             return False
