@@ -31,7 +31,7 @@ __all__ = [
 
 
 from datetime import datetime, date
-from email.Utils import formatdate
+from email.utils import formatdate
 import cgi
 import copy
 import os
@@ -122,6 +122,7 @@ from lazr.restful.interfaces import (
     IWebServiceVersion,
     LAZR_WEBSERVICE_NAME,
     )
+from lazr.restful.marshallers import URLDereferencingMixin
 from lazr.restful.utils import (
     extract_write_portion,
     get_current_web_service_request,
@@ -150,12 +151,12 @@ init_status_codes()
 
 def decode_value(value):
     """Return a unicode value curresponding to `value`."""
-    if isinstance(value, unicode):
+    if isinstance(value, six.text_type):
         return value
-    elif isinstance(value, str):
+    elif isinstance(value, bytes):
         return value.decode("utf-8")
     else:
-        return unicode(value)
+        return six.text_type(value)
 
 
 def encode_value(value):
@@ -163,17 +164,17 @@ def encode_value(value):
 
     Non-unicode strings are assumed to be UTF-8 already.
     """
-    if isinstance(value, unicode):
+    if isinstance(value, six.text_type):
         return value.encode("utf-8")
-    elif isinstance(value, str):
+    elif isinstance(value, bytes):
         return value
     else:
-        return str(value)
+        return bytes(value)
 
 
 def _default_html_renderer(value):
     """The default technique for rendering a value as an HTML snippet."""
-    return cgi.escape(unicode(value))
+    return cgi.escape(six.text_type(value))
 
 
 @adapter(Interface, IField, IWebServiceClientRequest)
@@ -253,7 +254,7 @@ class JSONItem:
 
 
 @implementer(IHTTPResource)
-class RedirectResource:
+class RedirectResource(URLDereferencingMixin):
     """A resource that redirects to another URL."""
 
     def __init__(self, url, request):
@@ -265,6 +266,10 @@ class RedirectResource:
         self.request.response.setStatus(301)
         self.request.response.setHeader("Location", url)
 
+    @property
+    def context(self):
+        return self.dereference_url_as_object(self.url)
+
 
 @implementer(IHTTPResource)
 class HTTPResource:
@@ -696,7 +701,7 @@ class CustomOperationResourceMixin:
         :return: The result of the operation: either a string or an
         object that needs to be serialized to JSON.
         """
-        if not isinstance(operation_name, basestring):
+        if not isinstance(operation_name, six.string_types):
             self.request.response.setStatus(400)
             return "Expected a single operation: %r" % (operation_name,)
 
@@ -722,7 +727,7 @@ class CustomOperationResourceMixin:
         :return: The result of the operation: either a string or an
         object that needs to be serialized to JSON.
         """
-        if not isinstance(operation_name, basestring):
+        if not isinstance(operation_name, six.string_types):
             self.request.response.setStatus(400)
             return "Expected a single operation: %r" % (operation_name,)
 
@@ -1158,7 +1163,7 @@ class EntryManipulatingResource(ReadWriteResource):
                     # instead of whatever object the raise site
                     # thought would be a good idea.
                     if (len(e.args) > 0 and
-                        isinstance(e.args[0], basestring)):
+                        isinstance(e.args[0], six.string_types)):
                         error = e.args[0]
                     else:
                         error = "Constraint not satisfied."
@@ -1216,7 +1221,7 @@ class EntryManipulatingResource(ReadWriteResource):
             # The changeset contained new values for some of this object's
             # fields, and the notification event may have changed others.
             # Clear out any fields that changed.
-            for name, cached in self._unmarshalled_field_cache.items():
+            for name, cached in list(self._unmarshalled_field_cache.items()):
                 cached, (field, old_value, flag) = cached
                 if flag is IUnmarshallingDoesntNeedValue:
                     continue
@@ -1306,7 +1311,7 @@ class EntryFieldResource(FieldUnmarshallerMixin, EntryManipulatingResource):
         # generating the representation might itself change across
         # versions.
         revno = getUtility(IWebServiceConfiguration).code_revision
-        return [core.encode('utf-8') for core in [revno, unicode(value)]]
+        return [core.encode('utf-8') for core in [revno, six.text_type(value)]]
 
     def _representation(self, media_type):
         """Create a representation of the field value."""
@@ -1542,7 +1547,7 @@ class EntryResource(CustomOperationResourceMixin,
         operation_name = self.request.form.pop('ws.op', None)
         if operation_name is not None:
             result = self.handleCustomGET(operation_name)
-            if isinstance(result, basestring):
+            if isinstance(result, (bytes, six.text_type)):
                 # The custom operation took care of everything and
                 # just needs this string served to the client.
                 return result
@@ -1783,7 +1788,7 @@ class CollectionResource(BatchingResourceMixin,
         operation_name = self.request.form.pop('ws.op', None)
         if operation_name is not None:
             result = self.handleCustomGET(operation_name)
-            if isinstance(result, str) or isinstance(result, unicode):
+            if isinstance(result, (bytes, six.text_type)):
                 # The custom operation took care of everything and
                 # just needs this string served to the client.
                 return result
@@ -1981,14 +1986,14 @@ class ServiceRootResource(HTTPResource):
                         schema, self.request)
 
                     singular = adapter.singular_type
-                    assert not singular_names.has_key(singular), (
+                    assert singular not in singular_names, (
                         "Both %s and %s expose the singular name '%s'."
                         % (singular_names[singular].__name__,
                            schema.__name__, singular))
                     singular_names[singular] = schema
 
                     plural = adapter.plural_type
-                    assert not plural_names.has_key(plural), (
+                    assert plural not in plural_names, (
                         "Both %s and %s expose the plural name '%s'."
                         % (plural_names[plural].__name__,
                            schema.__name__, plural))
