@@ -2,6 +2,8 @@
 
 """Error handling on the webservice."""
 
+from __future__ import absolute_import, division, print_function
+
 __metaclass__ = type
 __all__ = [
     'ClientErrorView',
@@ -16,7 +18,7 @@ __all__ = [
 import traceback
 
 from zope.component import getUtility
-from zope.interface import implements
+from zope.interface import implementer
 
 try:
     # This import brings some big ugly dependencies, and is not strictly
@@ -37,9 +39,9 @@ from lazr.restful.interfaces import (
     )
 
 
+@implementer(IWebServiceExceptionView)
 class WebServiceExceptionView:
     """Generic view handling exceptions on the web service."""
-    implements(IWebServiceExceptionView)
 
     def __init__(self, context, request):
         self.context = context
@@ -56,7 +58,7 @@ class WebServiceExceptionView:
 
     def isSystemError(self):
         """See `ISystemErrorView`."""
-        return self.status / 100 == 5
+        return self.status // 100 == 5
 
     def __call__(self):
         """Generate the HTTP response describing the exception."""
@@ -68,7 +70,7 @@ class WebServiceExceptionView:
 
         show_tracebacks = getUtility(
             IWebServiceConfiguration).show_tracebacks
-        server_error = self.status / 100 == 5
+        server_error = self.status // 100 == 5
         if (not show_tracebacks and server_error):
             # Don't show the exception message; it might contain
             # private information.
@@ -86,16 +88,16 @@ class WebServiceExceptionView:
 
 # lazr/restful/configure.zcml registers these classes as adapter
 # factories for common Zope exceptions.
+@implementer(ISystemErrorView)
 class ClientErrorView(WebServiceExceptionView):
     """Client-induced error."""
-    implements(ISystemErrorView)
 
     status = 400
 
 
+@implementer(ISystemErrorView)
 class SystemErrorView(WebServiceExceptionView):
     """Server error."""
-    implements(ISystemErrorView)
 
     status = 500
 
