@@ -3,11 +3,14 @@
 
 """Interface objects for the LAZR example web service."""
 
+from __future__ import absolute_import, print_function
+
 __metaclass__ = type
 __all__ = ['AlreadyNew',
            'Cuisine',
            'ICookbook',
            'ICookbookSet',
+           'ICookbookSubclass',
            'IDish',
            'IDishSet',
            'IFileManager',
@@ -26,11 +29,19 @@ from lazr.enum import EnumeratedType, Item
 from lazr.restful.fields import CollectionField, Reference
 from lazr.restful.interfaces import IByteStorage, ITopLevelEntryLink
 from lazr.restful.declarations import (
-    collection_default_content, export_as_webservice_collection,
-    export_as_webservice_entry, export_destructor_operation,
-    export_factory_operation, export_read_operation, export_write_operation,
-    exported, operation_parameters, operation_returns_collection_of,
-    operation_returns_entry, webservice_error)
+    collection_default_content,
+    export_destructor_operation,
+    export_factory_operation,
+    export_read_operation,
+    export_write_operation,
+    exported,
+    exported_as_webservice_collection,
+    exported_as_webservice_entry,
+    operation_parameters,
+    operation_returns_collection_of,
+    operation_returns_entry,
+    webservice_error,
+    )
 
 
 class AlreadyNew(Exception):
@@ -70,9 +81,9 @@ class IHasGet(Interface):
         """Traverse to a contained object."""
 
 
+@exported_as_webservice_entry(plural_name='dishes')
 class IDish(ILocation):
     """A dish, annotated for export to the web service."""
-    export_as_webservice_entry(plural_name='dishes')
     name = exported(TextLine(title=u"Name", required=True))
     recipes = exported(CollectionField(
             title=u"Recipes in this cookbook",
@@ -82,9 +93,9 @@ class IDish(ILocation):
         """Remove one of this dish's recipes."""
 
 
+@exported_as_webservice_entry()
 class IRecipe(ILocation):
     """A recipe, annotated for export to the web service."""
-    export_as_webservice_entry()
     id = exported(Int(title=u"Unique ID", required=True))
     dish = exported(Reference(title=u"Dish", schema=IDish))
     cookbook = exported(Reference(title=u"Cookbook", schema=Interface))
@@ -101,9 +112,9 @@ class IRecipe(ILocation):
         """Delete the recipe."""
 
 
+@exported_as_webservice_entry()
 class ICookbook(IHasGet, ILocation):
     """A cookbook, annotated for export to the web service."""
-    export_as_webservice_entry()
     name = exported(TextLine(title=u"Name", required=True))
     copyright_date = exported(
         Date(title=u"Copyright Date",
@@ -162,6 +173,7 @@ IDish['recipes'].value_type.schema = IRecipe
 IRecipe['cookbook'].schema = ICookbook
 
 
+@exported_as_webservice_entry()
 class ICookbookSubclass(ICookbook):
     """A published subclass of ICookbook.
 
@@ -169,16 +181,15 @@ class ICookbookSubclass(ICookbook):
     a published entry interface that subclasses another published
     entry interface.
     """
-    export_as_webservice_entry()
 
 
 class IFeaturedCookbookLink(ITopLevelEntryLink):
     """A marker interface."""
 
 
+@exported_as_webservice_collection(ICookbook)
 class ICookbookSet(IHasGet):
     """The set of all cookbooks, annotated for export to the web service."""
-    export_as_webservice_collection(ICookbook)
 
     @collection_default_content()
     def getCookbooks():
@@ -211,18 +222,18 @@ class ICookbookSet(IHasGet):
     featured = Attribute("The currently featured cookbook.")
 
 
+@exported_as_webservice_collection(IDish)
 class IDishSet(IHasGet):
     """The set of all dishes, annotated for export to the web service."""
-    export_as_webservice_collection(IDish)
 
     @collection_default_content()
     def getDishes():
         """Return the list of dishes."""
 
 
+@exported_as_webservice_collection(IRecipe)
 class IRecipeSet(IHasGet):
     """The set of all recipes, annotated for export to the web service."""
-    export_as_webservice_collection(IRecipe)
 
     @collection_default_content()
     def getRecipes():
