@@ -2,6 +2,8 @@
 
 """Data model objects for the LAZR example web service."""
 
+from __future__ import absolute_import, print_function
+
 __metaclass__ = type
 __all__ = ['Cookbook',
            'CookbookServiceRootResource',
@@ -13,9 +15,9 @@ from datetime import date
 
 import grokcore.component
 
-from zope.interface import implements
+from zope.interface import implementer
 from zope.location.interfaces import ILocation
-from zope.component import adapts, getMultiAdapter, getUtility
+from zope.component import getMultiAdapter, getUtility
 from zope.schema.interfaces import IBytes
 
 from lazr.restful import directives, ServiceRootResource
@@ -36,10 +38,10 @@ class CookbookWebServiceObject:
     """A basic object published through the web service."""
 
 
+@implementer(IByteStorage, ILocation)
 class SimpleByteStorage(CookbookWebServiceObject,
                         grokcore.component.MultiAdapter):
     """A simple IByteStorage implementation"""
-    implements(IByteStorage, ILocation)
     grokcore.component.adapts(IEntry, IBytes)
     grokcore.component.provides(IByteStorage)
 
@@ -87,9 +89,9 @@ class SimpleByteStorage(CookbookWebServiceObject,
         setattr(self.entry, self.field.__name__, None)
 
 
+@implementer(ICookbook)
 class Cookbook(CookbookWebServiceObject):
     """An object representing a cookbook"""
-    implements(ICookbook)
     def __init__(self, name, description, cuisine, copyright_date,
                  last_printing=None, price=0, confirmed=False):
         self.name = name
@@ -153,8 +155,8 @@ class Cookbook(CookbookWebServiceObject):
         storage.createStored('application/octet-stream', cover, 'cover')
 
 
+@implementer(IDish)
 class Dish(CookbookWebServiceObject):
-    implements(IDish)
 
     def __init__(self, name):
         self.name = name
@@ -172,8 +174,8 @@ class Dish(CookbookWebServiceObject):
         self.recipes.remove(recipe)
 
 
+@implementer(IRecipe)
 class Recipe(CookbookWebServiceObject):
-    implements(IRecipe)
 
     def __init__(self, id, cookbook, dish, instructions, private=False):
         self.id = id
@@ -197,10 +199,10 @@ class Recipe(CookbookWebServiceObject):
         getUtility(IRecipeSet).removeRecipe(self)
 
 # Top-level objects.
+@implementer(ILocation)
 class CookbookTopLevelObject(CookbookWebServiceObject,
                              grokcore.component.GlobalUtility):
     """An object published at the top level of the web service."""
-    implements(ILocation)
 
     @property
     def __parent__(self):
@@ -211,9 +213,9 @@ class CookbookTopLevelObject(CookbookWebServiceObject,
         raise NotImplementedError()
 
 
+@implementer(ITopLevelEntryLink)
 class FeaturedCookbookLink(CookbookTopLevelObject):
     """A link to the currently featured cookbook."""
-    implements(ITopLevelEntryLink)
     grokcore.component.provides(ITopLevelEntryLink)
 
     @property
@@ -226,9 +228,9 @@ class FeaturedCookbookLink(CookbookTopLevelObject):
     entry_type = ICookbook
 
 
+@implementer(ICookbookSet)
 class CookbookSet(CookbookTopLevelObject):
     """The set of all cookbooks."""
-    implements(ICookbookSet)
     grokcore.component.provides(ICookbookSet)
 
     __name__ = "cookbooks"
@@ -275,9 +277,9 @@ class CookbookSet(CookbookTopLevelObject):
         return cookbook
 
 
+@implementer(IDishSet)
 class DishSet(CookbookTopLevelObject):
     """The set of all dishes."""
-    implements(IDishSet)
     grokcore.component.provides(IDishSet)
 
     __name__ = "dishes"
@@ -297,9 +299,9 @@ class DishSet(CookbookTopLevelObject):
         return None
 
 
+@implementer(IRecipeSet)
 class RecipeSet(CookbookTopLevelObject):
     """The set of all recipes."""
-    implements(IRecipeSet)
     grokcore.component.provides(IRecipeSet)
 
     __name__ = "recipes"
@@ -359,13 +361,13 @@ RECIPES = [C1_D1, C2_D1, C3_D1, C2_D2, C3_D2, C1_D3]
 
 
 # Define classes for the service root.
+@implementer(IHasGet)
 class CookbookServiceRootResource(ServiceRootResource):
     """A service root for the cookbook web service.
 
     Traversal to top-level resources is handled with the get() method.
     The top-level objects are stored in the top_level_names dict.
     """
-    implements(IHasGet)
 
     @property
     def top_level_names(self):
