@@ -2,6 +2,8 @@
 
 """Test harness for LAZR doctests."""
 
+from __future__ import absolute_import, print_function
+
 __metaclass__ = type
 __all__ = []
 
@@ -9,8 +11,6 @@ import os
 import doctest
 from pkg_resources import resource_filename
 
-from zope.configuration import xmlconfig
-from zope.testing.cleanup import cleanUp
 from van.testing.layer import zcml_layer, wsgi_intercept_layer
 
 from lazr.restful.example.base.root import CookbookServiceRootResource
@@ -41,12 +41,18 @@ class WSGILayer(FunctionalLayer):
 wsgi_intercept_layer(WSGILayer)
 
 
-def additional_tests():
+def load_tests(loader, tests, pattern):
     """See `zope.testing.testrunner`."""
-    tests = sorted(
+    doctest_files = sorted(
         [name
          for name in os.listdir(os.path.dirname(__file__))
          if name.endswith('.txt')])
-    suite = doctest.DocFileSuite(optionflags=DOCTEST_FLAGS, *tests)
+    globs = {
+        'absolute_import': absolute_import,
+        'print_function': print_function,
+        }
+    suite = doctest.DocFileSuite(
+        *doctest_files, optionflags=DOCTEST_FLAGS, globs=globs)
     suite.layer = WSGILayer
-    return suite
+    tests.addTest(suite)
+    return tests
