@@ -2,6 +2,8 @@
 
 """Test harness for LAZR doctests."""
 
+from __future__ import absolute_import, print_function
+
 __metaclass__ = type
 __all__ = []
 
@@ -30,9 +32,15 @@ class WSGILayer(FunctionalLayer):
 wsgi_intercept_layer(WSGILayer)
 
 
-def additional_tests():
+def load_tests(loader, tests, pattern):
     """See `zope.testing.testrunner`."""
-    tests = ['../README.txt']
-    suite = doctest.DocFileSuite(optionflags=DOCTEST_FLAGS, *tests)
+    doctest_files = ['../README.txt']
+    globs = {
+        'absolute_import': absolute_import,
+        'print_function': print_function,
+        }
+    suite = doctest.DocFileSuite(
+        *doctest_files, optionflags=DOCTEST_FLAGS, globs=globs)
     suite.layer = WSGILayer
-    return suite
+    tests.addTest(suite)
+    return tests
