@@ -207,7 +207,7 @@ class RootResource(ServiceRootResource, TraverseWithGet):
 
     @property
     def top_level_names(self):
-        return self.top_level_objects.keys()
+        return list(self.top_level_objects.keys())
 
     def get(self, request, name):
         """Traverse to a top-level object."""
