@@ -50,7 +50,9 @@ def encode_response(response):
 
     :param response: an httplib HTTPResponse object.
     """
-    response_unicode = str(response).decode("utf-8")
+    response_unicode = str(response)
+    if isinstance(response_unicode, bytes):  # Python 2
+        response_unicode = response_unicode.decode("utf-8")
     return encode_unicode(response_unicode)
 
 
