@@ -20,7 +20,7 @@ __all__ = [
     'WebServiceTestPublication',
     ]
 
-from cStringIO import StringIO
+from io import BytesIO
 import simplejson
 import sys
 from types import ModuleType
@@ -28,6 +28,7 @@ import unittest
 
 import wsgi_intercept
 
+import six
 from six.moves.urllib.parse import (
     quote,
     urlencode,
@@ -81,10 +82,10 @@ def create_web_service_request(path_info, method='GET', body=None,
     if environ is not None:
         test_environ.update(environ)
     if body is None:
-        body_instream = StringIO('')
+        body_instream = BytesIO(b'')
     else:
         test_environ['CONTENT_LENGTH'] = len(body)
-        body_instream = StringIO(body)
+        body_instream = BytesIO(body)
     request = config.createRequest(body_instream, test_environ)
 
     request.processInputs()
@@ -122,7 +123,7 @@ class FakeResponse:
         if result is None:
             result = ''
 
-        if not isinstance(result, basestring):
+        if not isinstance(result, six.string_types):
             raise ValueError('only strings and None results are handled')
 
         self.result = result
@@ -209,7 +210,7 @@ class WebServiceApplication(Application):
     """
 
     def __init__(self, global_config, publication, **options):
-        if isinstance(publication, basestring):
+        if isinstance(publication, six.string_types):
             Application.__init__(self, global_config, publication, **options)
         else:
             self.publication = publication(global_config, **options)
@@ -334,7 +335,7 @@ class WebServiceCaller:
         # To be properly marshalled all values must be strings or converted to
         # JSON.
         for key, value in args.items():
-            if not isinstance(value, basestring):
+            if not isinstance(value, six.string_types):
                 args[key] = simplejson.dumps(value)
         return urlencode(args)
 
@@ -363,7 +364,7 @@ class WebServiceCaller:
 
         This may mean turning the value into a JSON string.
         """
-        if not isinstance(value, basestring):
+        if not isinstance(value, six.string_types):
             value = simplejson.dumps(value)
         return quote(value)
 
@@ -408,7 +409,7 @@ class WebServiceResponseWrapper(ProxyBase):
     def jsonBody(self):
         """Return the body of the web service request as a JSON document."""
         try:
-            json = simplejson.loads(unicode(self.body))
+            json = simplejson.loads(six.ensure_text(self.body))
             if isinstance(json, list):
                 json = sorted(json)
             return json
