@@ -58,5 +58,5 @@ def load_tests(loader, tests, pattern):
         }
     tests.addTest(doctest.DocFileSuite(
         *doctest_files, module_relative=False, optionflags=DOCTEST_FLAGS,
-        tearDown=tearDown, globs=globs))
+        tearDown=tearDown, globs=globs, encoding='UTF-8'))
     return tests
