@@ -31,6 +31,7 @@ import string
 import subprocess
 
 from simplejson import encoder
+import six
 
 from zope.component import getUtility
 from zope.schema import getFieldsInOrder
@@ -359,7 +360,7 @@ def safe_hasattr(ob, name):
 
 def smartquote(str):
     """Return a copy of the string, with typographical quote marks applied."""
-    str = unicode(str)
+    str = six.text_type(str)
     str = re.compile(u'(^| )(")([^" ])').sub(u'\\1\u201c\\3', str)
     str = re.compile(u'([^ "])(")($|[\s.,;:!?])').sub(u'\\1\u201d\\3', str)
     return str
